######################################################################
#
# EPrints::MetaField::Uuid;
#
######################################################################
#
#
# Copyright 2000-2008 University of Southampton. All Rights Reserved.
# 
#  This file is part of GNU EPrints 3.
#  
#  Copyright (c) 2000-2008 University of Southampton, UK. SO17 1BJ.
#  
#  EPrints 3 is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  
#  EPrints 3 is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License
#  along with EPrints 3; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
######################################################################

=pod

=head1 NAME

B<EPrints::MetaField::Uuid> - globally unique identifier

=head1 DESCRIPTION

This field type automatically generates a UUID based on L<APR::UUID>, which is
part of mod_perl. The UUID is prepended with "urn:uuid:" to namespace it to the
global system of UUID URIs.

=over 4

=cut

package EPrints::MetaField::Uuid;

use APR::UUID;
use EPrints::MetaField::Text;

@ISA = qw( EPrints::MetaField::Text );

use strict;

sub get_property_defaults
{
	my( $self ) = @_;
	my %defaults = $self->SUPER::get_property_defaults;
	$defaults{text_index} = 0;
	$defaults{maxlength} = 45;
	return %defaults;
}

sub get_default_value
{
	my( $self, $session ) = @_;

	return "urn:uuid:" . APR::UUID->new->format();
}

######################################################################
1;
